# Export FCS

Exports FCS files from after this operation. Only really useful if you’ve done a calibration step or created derivative channels using the ratio option. As you set the options, the main plot shows a table of the files that will be created.

Base
The prefix of the FCS file names

By

  A list of metadata attributes to aggregate the data before exporting. For example, if the experiment has two pieces of metadata, `Time` and `Dox`, setting By to `["Time", "Dox"]` will export one file for each subset of the data with a unique combination of `Time` and `Dox`.

Keywords

  If you want to add more keywords to the FCS files’ TEXT segment, specify them here.

Export...

  Choose a folder and export the FCS files.